@@ -99,7 +99,7 @@ def register_parser(content_type, parser):
     @param parser: The parser.
     @type parser: Parser
     '''
-    if RENDERINGS.has_key(content_type):
+    if content_type in RENDERINGS.keys():
         raise AlreadyRegisteredException('A Parser for this'
                                          + ' Content-type has already been'
                                          + ' registered.')
@@ -118,7 +118,7 @@ def get_parser(content_type):
             # dropping those ;q=x.x values...
             type_str = type_str[:type_str.find(';q=')]
 
-        if RENDERINGS.has_key(type_str):
+        if type_str in RENDERINGS.keys():
             parser = RENDERINGS[type_str]
             break
         elif type_str == '*/*':
